@@ -20,7 +20,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.  */
 
-#include "gradient.h"
+#include <meta/gradient.h>
 #include <gtk/gtk.h>
 
 typedef void (* RenderGradientFunc) (cairo_t     *cr,
